/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef } from "@angular/core";
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI DragHandle directive for Angular.
 * Use this directive to specify an element inside a drag target as a handle for dragging instead of the drag target itself.
 *
 * ```html
 * <div kendoDragTarget>
 *  <button kendoDragHandle kendoButton>
 *   Drag me
 *  </button>
 * </div>
 * ```
 */
export declare class DragHandleDirective {
    element: ElementRef;
    touchActionStyle: string;
    /**
     * Sets the cursor style of the drag handle. Accepts same values as the [CSS `cursor` property](https://developer.mozilla.org/en-US/docs/Web/CSS/cursor#values).
     *
     * @default 'move'
     */
    cursorStyle: string;
    constructor(element: ElementRef);
    static ɵfac: i0.ɵɵFactoryDeclaration<DragHandleDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DragHandleDirective, "[kendoDragHandle]", ["kendoDragHandle"], { "cursorStyle": { "alias": "cursorStyle"; "required": false; }; }, {}, never, never, true, never>;
}
