/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, EventEmitter, NgZone, OnDestroy, OnInit } from "@angular/core";
import { NormalizedDragEvent } from "@progress/kendo-draggable-common";
import { DragStateService } from "./drag-state.service";
import { DropTargetEvent } from './events/drop-target-event';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI DropTarget directive for Angular.
 * Use this directive to make an element a drop target for draggable items.
 *
 * ```html
 * <div kendoDropTarget>
 *   Drop here
 * </div>
 * ```
 *
 */
export declare class DropTargetDirective implements OnInit, OnDestroy {
    private service;
    private element;
    private ngZone;
    /**
     * Fires when a drag target enters the drop target.
     */
    onDragEnter: EventEmitter<DropTargetEvent>;
    /**
     * Fires when a drag target is dragged over the drop target.
     */
    onDragOver: EventEmitter<DropTargetEvent>;
    /**
     * Fires when a drag target leaves the drop target.
     */
    onDragLeave: EventEmitter<DropTargetEvent>;
    /**
     * Fires when a drag target is dropped over the drop target.
     */
    onDrop: EventEmitter<DropTargetEvent>;
    constructor(service: DragStateService, element: ElementRef, ngZone: NgZone);
    private dropTarget;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    handleDragEnter(event: NormalizedDragEvent): void;
    /**
     * @hidden
     */
    handleDragLeave(event: NormalizedDragEvent): void;
    /**
     * @hidden
     */
    handleDragOver(event: NormalizedDragEvent): void;
    /**
     * @hidden
     */
    handleDrop(event: NormalizedDragEvent): void;
    private initializeDropTarget;
    private emitZoneAwareEvent;
    static ɵfac: i0.ɵɵFactoryDeclaration<DropTargetDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DropTargetDirective, "[kendoDropTarget]", ["kendoDropTarget"], {}, { "onDragEnter": "onDragEnter"; "onDragOver": "onDragOver"; "onDragLeave": "onDragLeave"; "onDrop": "onDrop"; }, never, never, true, never>;
}
