/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NormalizedDragEvent } from "@progress/kendo-draggable-common";
/**
 * Arguments for the drag events of the `DropTarget` and `DropTargetContainer` directives.
 */
export declare class DropTargetEvent {
    /**
     * The current drag target element.
     */
    dragTarget: HTMLElement;
    /**
     * The current drop target element.
     */
    dropTarget: HTMLElement;
    /**
     * The information related to the current drag event.
     */
    dragEvent: NormalizedDragEvent;
    /**
     * The data passed to the `dragData` input property of the `DragTarget` or `DragTargetContainer` directive.
     */
    dragData: any;
    /**
     * The index of the current drop target in the collection of drop targets. Applies to `DropTargetContainer` directive.
     */
    dropTargetIndex?: number;
    /**
     * The hint element of the `DragTarget`.
     */
    hintElement?: HTMLElement;
    /**
     * Left for backward compatibility for the DropTarget deprecated events.
     * @hidden
     */
    get normalizedEvent(): NormalizedDragEvent;
    /**
     * Left for backward compatibility for the DropTarget deprecated events.
     * @hidden
     */
    get hostElement(): HTMLElement;
    /**
     * @hidden
     */
    constructor(args?: any);
}
