/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { DragHandleDirective } from "./drag-and-drop/draghandle.directive";
import { DragTargetContainerDirective } from "./drag-and-drop/dragtarget-container.directive";
import { DragTargetDirective } from "./drag-and-drop/dragtarget.directive";
import { DropTargetContainerDirective } from "./drag-and-drop/droptarget-container.directive";
import { DropTargetDirective } from "./drag-and-drop/droptarget.directive";
import { HintComponent } from "./drag-and-drop/hint.component";
/**
 * Use this utility array to access all Drag and Drop-related components and directives in a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_DRAGANDDROP } from '@progress/kendo-angular-utils';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_DRAGANDDROP],
 *   template: `
 *      <div kendoDragTarget>Drag me</div>
 *      <div kendoDropTarget>Drop here</div>
 *   `
 * })
 * export class AppComponent {}
 * ```
 */
export const KENDO_DRAGANDDROP = [
    DragTargetDirective,
    DragHandleDirective,
    DropTargetDirective,
    DragTargetContainerDirective,
    DropTargetContainerDirective,
    HintComponent
];
/**
* Use this utility array to access all `@progress/kendo-angular-utils`-related components and directives in a standalone Angular component.
* > Currently, `KENDO_UTILS` includes only the `KENDO_DRAGANDDROP` utility array and their usage is equivalent.
*/
export const KENDO_UTILS = [
    ...KENDO_DRAGANDDROP
];
